@@ -258,7 +258,7 @@ static int http_response_parse_header_name(const char *key, size_t keylen) {
     return 0;
 }
 
-static void http_response_set_date_header(String *response) {
+zend_string *php_swoole_http_get_date() {
     time_t now = time(nullptr);
     if (now != date_cache.time) {
         if (date_cache.date) {
@@ -267,8 +267,13 @@ static void http_response_set_date_header(String *response) {
         date_cache.time = now;
         date_cache.date = php_format_date((char *) ZEND_STRL(SW_HTTP_DATE_FORMAT), now, 0);
     }
+    return date_cache.date;
+}
+
+static void http_response_set_date_header(String *response) {
+	auto date_str = php_swoole_http_get_date();
     response->append(ZEND_STRL("Date: "));
-    response->append(ZSTR_VAL(date_cache.date), ZSTR_LEN(date_cache.date));
+    response->append(ZSTR_VAL(date_str), ZSTR_LEN(date_str));
     response->append(ZEND_STRL("\r\n"));
 }
 
@@ -1175,7 +1180,7 @@ static PHP_METHOD(swoole_http_response, ping) {
     ZEND_PARSE_PARAMETERS_END_EX(RETURN_FALSE);
 
     if (ctx->http2) {
-        SW_CHECK_RETURN(swoole_http2_server_ping(ctx));
+        RETURN_BOOL(swoole_http2_server_ping(ctx));
     } else if (ctx->websocket) {
         String *buffer = ctx->get_write_buffer();
         buffer->clear();
@@ -1207,7 +1212,7 @@ static PHP_METHOD(swoole_http_response, goaway) {
     Z_PARAM_STRING(debug_data, debug_data_len)
     ZEND_PARSE_PARAMETERS_END_EX(RETURN_FALSE);
 
-    SW_CHECK_RETURN(swoole_http2_server_goaway(ctx, error_code, debug_data, debug_data_len));
+    RETURN_BOOL(swoole_http2_server_goaway(ctx, error_code, debug_data, debug_data_len));
 }
 
 static PHP_METHOD(swoole_http_response, upgrade) {
@@ -1287,6 +1292,7 @@ ssize_t WebSocket::send_frame(const swoole::WebSocketSettings &settings,
         sw_set_bit(flags, WebSocket::FLAG_MASK);
     }
     auto wbuf = sock->get_write_buffer();
+    wbuf->clear();
     WebSocket::encode(wbuf, payload, payload_length, opcode, flags);
     return sock->send(wbuf->str, wbuf->length);
 }
